==> zio-aws-ec2_2.12-6.20.78.3-sources.jar: zio/aws/ec2/model/ElasticGpuSpecificationResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ElasticGpuSpecificationResponse(
    `type`: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ElasticGpuSpecificationResponse = {
    import ElasticGpuSpecificationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ElasticGpuSpecificationResponse
      .builder()
      .optionallyWith(`type`.map(value => value: java.lang.String))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ElasticGpuSpecificationResponse.ReadOnly =
    zio.aws.ec2.model.ElasticGpuSpecificationResponse.wrap(buildAwsValue())
}
object ElasticGpuSpecificationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ElasticGpuSpecificationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ElasticGpuSpecificationResponse =
      zio.aws.ec2.model
        .ElasticGpuSpecificationResponse(`type`.map(value => value))
    def `type`: Optional[String]
    def getType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ElasticGpuSpecificationResponse
  ) extends zio.aws.ec2.model.ElasticGpuSpecificationResponse.ReadOnly {
    override val `type`: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.`type`())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ElasticGpuSpecificationResponse
  ): zio.aws.ec2.model.ElasticGpuSpecificationResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-5.17.102.9-sources.jar: zio/aws/ec2/model/ElasticGpuSpecificationResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ElasticGpuSpecificationResponse(
    `type`: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ElasticGpuSpecificationResponse = {
    import ElasticGpuSpecificationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ElasticGpuSpecificationResponse
      .builder()
      .optionallyWith(`type`.map(value => value: java.lang.String))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ElasticGpuSpecificationResponse.ReadOnly =
    zio.aws.ec2.model.ElasticGpuSpecificationResponse.wrap(buildAwsValue())
}
object ElasticGpuSpecificationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ElasticGpuSpecificationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ElasticGpuSpecificationResponse =
      zio.aws.ec2.model
        .ElasticGpuSpecificationResponse(`type`.map(value => value))
    def `type`: Option[String]
    def getType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ElasticGpuSpecificationResponse
  ) extends zio.aws.ec2.model.ElasticGpuSpecificationResponse.ReadOnly {
    override val `type`: Option[String] =
      scala.Option(impl.`type`()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ElasticGpuSpecificationResponse
  ): zio.aws.ec2.model.ElasticGpuSpecificationResponse.ReadOnly = new Wrapper(
    impl
  )
}
